==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/it/details.php <==
<?php

global $details_text;
$details_text = array (

'task'				=>	'Task',
'edittask'				=>	'Modifica questo task',
'openedby'			=>	'Aperto da',
'editedby'			=>	'Ultima modifica da parte di',
'tasktype'			=>	'Tipo di task',
'category'			=>	'Categoria',
'status'			=>	'Status',
'assignedto'		=>	'Assegnato a',
'noone'				=>	'Nessuno',
'operatingsystem'	=>	'Sistema operativo',
'severity'			=>	'Gravita\'',
'reportedversion'	=>	'Riportato nella Versione',
'dueinversion'		=>	'Dovuto per la Versione',
'undecided'			=>	'Non deciso',
'percentcomplete'	=>	'Percentuale Completata',
'details'			=>	'Dettagli',
'savedetails'		=>	'Salva Dettagli',
'canceledit'		=>	'Cancella Modifiche',
'anonymous'			=>	'Origine anonima',
'complete'			=>	'completato',
'closedby'			=>	'Chiuso da',
'reasonforclosing'	=>	'Motivo per chiuderlo:',
'reopenthistask'	=>	'Riapri questo task',
'closetask'			=>	'Chiudi Task',
'comments'			=>	'Commenti',
'attachments'		=>	'Allegati',
'relatedtasks'		=>	'Task correlati',
'notifications'		=>	'Notifiche',
'edit'				=>	'Modifica',
'delete'			=>	'Cancella',
'commentby'			=>	'Commento a cura di',
'addcomment'		=>	'Aggiungi commento',
'fileuploadedby'	=>	'File caricato da',
'uploadafile'		=>	'Carica un file come attach',
'description'		=>	'Descrizione',
'uploadnow'			=>	'Carica ora!',
'thesearerelated'	=>	'Questi task sono correlati a questo task',
'remove'			=>	'Rimuovi',
'addnewrelated'		=>	'Aggiungi un nuovo task correlato',
'add'				=>	'Aggoingi!',
'otherrelated'		=>	'Altri task correlati',
'receivenotify'		=>	'Questi utenti riceveranno una notifica dettagliata quando questo task ha variazioni.',
'addusertolist'		=>	'Aggiungi un utente a questa lista',
'addtolist'			=>	'Aggiungi alla lista',
'addmyself'			=>	'Aggiungi il sottoscritto a questa lista',
'removemyself'		=>	'Rimuovi il sottoscritto da questa lista',
'invalidtaskid'		=>	'Non c\'e\' alcun task con questo identificativo',
'theseusersnotify'	=>	'Questi utenti riceveranno una notifica dettagliata quando questo task ha variazioni.',

// Added in version 0.9.5

'attachedtoproject'	=>	'Allegato al progetto',

// Added in version 0.9.6

'reminders'         =>   'Promemoria',
'system'            =>   'Sistema',
'remindthisuser'    =>   'Manda un promemoria a questo utente',
'thisoften'         =>   'Quanto spesso',
'startafter'        =>   'Aspetta prima di inviare promemoria',
'hours'             =>   'Ora(e)',
'days'              =>   'Giorno(i)',
'weeks'             =>   'Settimana(e)',
'addreminder'       =>   'Aggiungi promemoria',
'defaultreminder'   =>   'Questo e\' un promemoria di controllare il seguente task di flyspray:',
'message'           =>   'Messaggio',
'closed'			=>   'Chiuso',
'filename'			=>   'Nome file:',
'date'				=>   'Data:',
'filesize'			=>   'Dimensione File:',
'closurecomment'	=>   'Commenti addizionali sulla chiusura:',

'history'           =>   'Storico',
'nohistory'         =>   'Non c\'e\' storico disponibile',
'eventdate'         =>   'Data',
'user'              =>   'Utente',
'event'             =>   'Evento',
'fieldchanged'      =>   'Campo cambiato',
'taskopened'        =>   'Task aperto',
'taskreopened'      =>   'Task riaperto',
'taskclosed'        =>   'Task chiuso',
'commentadded'      =>   'Aggiunto commento',
'commentedited'     =>   'Modificato commento',
'commentdeleted'    =>   'Cancellato commento',
'attachmentadded'   =>   'Aggiunto attachment',
'attachmentdeleted' =>   'Cancellato attachment',
'taskedited'        =>   'Modificati i dettagli del Task',
'notificationadded' =>   'Aggiunto utente alla lista di notifica',
'notificationdeleted' => 'Rimosso utente dalla lista di notifica',
'relatedadded'      =>   'Aggiunto task correlato',
'relateddeleted'    =>   'Rimosso task correlato',
'taskassigned'      =>   'Task assegnato a',
'taskreassigned'    =>   'Task riassegnato a',
'assignmentremoved' =>   'Assegnazione rimossa',
'summary'           =>   'Sommario',
'addedasrelated'    =>   'Aggiunto task alla lista correlata a',
'deletedasrelated'  =>   'Rimosso task dalla lista correlata a',
'reminderadded'     =>   'Aggiunto promemoria',
'reminderdeleted'   =>   'Rimosso promemoria',
'priority'          =>   'Priorita\'',
'previousvalue'     =>   'Valore precedente',
'newvalue'          =>   'Nuovo valore',

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/it/details.php <==
<?php

global $details_text;
$details_text = array (

'task'				=>	'Task',
'edittask'				=>	'Modifica questo task',
'openedby'			=>	'Aperto da',
'editedby'			=>	'Ultima modifica da parte di',
'tasktype'			=>	'Tipo di task',
'category'			=>	'Categoria',
'status'			=>	'Status',
'assignedto'		=>	'Assegnato a',
'noone'				=>	'Nessuno',
'operatingsystem'	=>	'Sistema operativo',
'severity'			=>	'Gravita\'',
'reportedversion'	=>	'Riportato nella Versione',
'dueinversion'		=>	'Dovuto per la Versione',
'undecided'			=>	'Non deciso',
'percentcomplete'	=>	'Percentuale Completata',
'details'			=>	'Dettagli',
'savedetails'		=>	'Salva Dettagli',
'canceledit'		=>	'Cancella Modifiche',
'anonymous'			=>	'Origine anonima',
'complete'			=>	'completato',
'closedby'			=>	'Chiuso da',
'reasonforclosing'	=>	'Motivo per chiuderlo:',
'reopenthistask'	=>	'Riapri questo task',
'closetask'			=>	'Chiudi Task',
'comments'			=>	'Commenti',
'attachments'		=>	'Allegati',
'relatedtasks'		=>	'Task correlati',
'notifications'		=>	'Notifiche',
'edit'				=>	'Modifica',
'delete'			=>	'Cancella',
'commentby'			=>	'Commento a cura di',
'addcomment'		=>	'Aggiungi commento',
'fileuploadedby'	=>	'File caricato da',
'uploadafile'		=>	'Carica un file come attach',
'description'		=>	'Descrizione',
'uploadnow'			=>	'Carica ora!',
'thesearerelated'	=>	'Questi task sono correlati a questo task',
'remove'			=>	'Rimuovi',
'addnewrelated'		=>	'Aggiungi un nuovo task correlato',
'add'				=>	'Aggoingi!',
'otherrelated'		=>	'Altri task correlati',
'receivenotify'		=>	'Questi utenti riceveranno una notifica dettagliata quando questo task ha variazioni.',
'addusertolist'		=>	'Aggiungi un utente a questa lista',
'addtolist'			=>	'Aggiungi alla lista',
'addmyself'			=>	'Aggiungi il sottoscritto a questa lista',
'removemyself'		=>	'Rimuovi il sottoscritto da questa lista',
'invalidtaskid'		=>	'Non c\'e\' alcun task con questo identificativo',
'theseusersnotify'	=>	'Questi utenti riceveranno una notifica dettagliata quando questo task ha variazioni.',

// Added in version 0.9.5

'attachedtoproject'	=>	'Allegato al progetto',

// Added in version 0.9.6

'reminders'         =>   'Promemoria',
'system'            =>   'Sistema',
'remindthisuser'    =>   'Manda un promemoria a questo utente',
'thisoften'         =>   'Quanto spesso',
'startafter'        =>   'Aspetta prima di inviare promemoria',
'hours'             =>   'Ora(e)',
'days'              =>   'Giorno(i)',
'weeks'             =>   'Settimana(e)',
'addreminder'       =>   'Aggiungi promemoria',
'defaultreminder'   =>   'Questo e\' un promemoria di controllare il seguente task di flyspray:',
'message'           =>   'Messaggio',
'closed'			=>   'Chiuso',
'filename'			=>   'Nome file:',
'date'				=>   'Data:',
'filesize'			=>   'Dimensione File:',
'closurecomment'	=>   'Commenti addizionali sulla chiusura:',

'history'           =>   'Storico',
'nohistory'         =>   'Non c\'e\' storico disponibile',
'eventdate'         =>   'Data',
'user'              =>   'Utente',
'event'             =>   'Evento',
'fieldchanged'      =>   'Campo cambiato',
'taskopened'        =>   'Task aperto',
'taskreopened'      =>   'Task riaperto',
'taskclosed'        =>   'Task chiuso',
'commentadded'      =>   'Aggiunto commento',
'commentedited'     =>   'Modificato commento',
'commentdeleted'    =>   'Cancellato commento',
'attachmentadded'   =>   'Aggiunto attachment',
'attachmentdeleted' =>   'Cancellato attachment',
'taskedited'        =>   'Modificati i dettagli del Task',
'notificationadded' =>   'Aggiunto utente alla lista di notifica',
'notificationdeleted' => 'Rimosso utente dalla lista di notifica',
'relatedadded'      =>   'Aggiunto task correlato',
'relateddeleted'    =>   'Rimosso task correlato',
'taskassigned'      =>   'Task assegnato a',
'taskreassigned'    =>   'Task riassegnato a',
'assignmentremoved' =>   'Assegnazione rimossa',
'summary'           =>   'Sommario',
'addedasrelated'    =>   'Aggiunto task alla lista correlata a',
'deletedasrelated'  =>   'Rimosso task dalla lista correlata a',
'reminderadded'     =>   'Aggiunto promemoria',
'reminderdeleted'   =>   'Rimosso promemoria',
'priority'          =>   'Priorita\'',
'previousvalue'     =>   'Valore precedente',
'newvalue'          =>   'Nuovo valore',

// Added in version 0.9.7

'selectareason'       =>   'Seleziona un motivo',
'assigntome'          =>   'Assegna a me',
'reopenrequest'       =>   'Richiedi la riapertura',
'requestclose'        =>   'Richiedi la chiusura',
'ownershiptaken'      =>   'L\'utente ha preso possesso',
'closerequestmade'    =>   'Richiedi la chiusura del task',
'reopenrequestmade'   =>   'IL task richiesto viene riaperto',
'taskdependson'       =>   'Questo task dipende da',
'taskblocks'          =>   'Questo task impedisce di chiudere questi altri',
'addnew'              =>   'Aggiungi nuovo',
'depadded'            =>   'Dependency added:',
'depaddedother'       =>   'Questo tash ha aggiunto dipendenze:',
'depremoved'          =>   'Dipendenza rimossa:',
'depremovedother'     =>   'Questo task e\' stato rimosso dalla lista di dipendenze di altri task:',
'showdetailserror'    =>   'Il task non esiste o non hai i permessi per visualizzarlo.',
'makeprivate'         =>   'Rendi privato',
'makepublic'          =>   'Rendi pubblico',
'taskmadeprivate'    =>    'Task reso privato',
'taskmadepublic'     =>    'Privacy eliminata - task reso pubblico',

                       
);
?>
